# GENERATED FILE - DO NOT EDIT
BUILDS = {'Darwin': {'sha256': 'aac91635c054788a09971180a1ab6403eb585975ad243dc7e23aa26bee0df050',
            'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201712191315-OSXIntel64.zip'},
 'Linux': {'sha256': '40ec293d9055cd14b6adff67759d7eca3cb9cecbafaabe98a6691fa6b317867a',
           'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-201712191315-Linux64.zip'}}